
;**********************************************************************
;                                                                     *
;    Filename:	    sequencer.asm                                     *
;    Date:         	21-11-2013                                        *
;    File Version:	0.1   modified                                    *
;                                                                     *
;    Author: 		Bart van Ewijk                                    *
;                                                                     * 
;                                                                     *
;**********************************************************************

	list      p=10F200            ; list directive to define processor
	#include <P10F200.inc>        ; processor specific variable definitions

	__CONFIG   _MCLRE_OFF & _CP_OFF & _WDT_OFF 

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file. 
; See respective data sheet for additional information on configuration word.

#define	out_A	GPIO,0 ; RX-poort of Antenna Relay (Latch)
#define out_B	GPIO,1 ; TX-poort of Antenna Relay (Latch)
#define out_C	GPIO,2 ; SSPA Tx on
#define in		GPIO,3 ; PTT in (active LOW)
#define time	.50	   ; Delay constant. For faster/slower change here

	CBLOCK	0x10
	temp
	temp1
	temp2
	temp3
	ENDC

;***** VARIABLE DEFINITIONS
;temp	EQU     0x10        ;example variable definition



;**********************************************************************
	ORG     0xFF             ; processor reset vector

; Internal RC calibration value is placed at location 0xFF by Microchip
; as a movlw k, where the k is a literal value.

	ORG     0x000             ; coding begins here
	movwf   OSCCAL            ; update register with factory cal value 


init
	movlw	B'00001000'		;GP3 input, GP2,1,0 output
	tris	GPIO			;shift in
;	bcf		CMCON0,CMPON	;Comperator off only needed voor 10F204 & 10F206
	movlw	B'00001111'		;weak-pullups on, enable wake-up on pin change
	option	
	clrf	GPIO			;reset ports




start	
	bsf	out_A			; make sure Ant Relay is switched to RX-poort
	movlw time
	call delay
	bcf	out_A	
	goto Main

Main
	btfsc	in			; wait for PTT to go LOW
	goto $-1
	call Output_on		; doing RX-to-TX sequence
	btfss	in			; wait for PTT to go HIGH
	goto $-1
	call Output_off		; doing TX-to-RX sequence
	goto Main


; RX to TX sequence
Output_on
	bsf	out_B
	movlw time
	call delay
	bcf	out_B
	nop
	bsf	out_C
	movlw time
	call delay
	retlw 0

; TX to RX sequence
Output_off
	bcf	out_C
	movlw time
	call delay
	bsf	out_A
	movlw time
	call delay
	bcf out_A
	movlw time
	call delay
	retlw 0

delay
	movwf	temp1			;wait for 1.88*(w) ms
	movlw	.255			; only test
	movwf	temp3			; only test
	decf	temp3,f
delay1
	goto $+1
	goto $+1
	goto $+1
	goto $+1
	goto $+1
	decfsz	temp3,f
	goto delay1
	decfsz temp1,f
	goto delay1-1
	retlw 0
	


	END                       ; directive 'end of program'
